@@ -97,8 +97,10 @@ void UserModel::populate()
         const K_UID uid = user.userId().nativeId();
         const K_GID gid = user.groupId().nativeId();
 
-        // Check between uid min/max
-        if (uid < PlasmaLoginSettings::getInstance().minimumUid() || uid > PlasmaLoginSettings::getInstance().maximumUid()) {
+        const bool inLogindDefRange = (uid >= PlasmaLoginSettings::getInstance().minimumUid() && uid <= PlasmaLoginSettings::getInstance().maximumUid());
+        // values are hardcoded in systemd. Search there for HOME_UID_MIN/HOME_UID_MAX
+        const bool inHomedRange = (uid >= 60001 && uid <= 60513);
+        if (!inLogindDefRange && !inHomedRange) {
             continue;
         }
 
